local addon = LibStub("AceAddon-3.0"):GetAddon("BurlexUID");
local module = addon:NewModule("Minimap");
---------------------------------------------------------------------------
local checkThirdParty, frame = function()
    local point, relativeTo, relativePoint, x, y = MinimapCluster:GetPoint();
    if (relativeTo ~= UIParent) then return true; end -- a third party minimap manager is involved
end;
local updateButtons = function()
    if (not MouseIsOver(Minimap)) and (buidChar.MapButtons) then
        MiniMapTracking:Hide();
        MinimapZoomIn:Hide();
        MinimapZoomOut:Hide();
        MiniMapWorldMapButton:Hide();
    else
        MinimapZoomIn:Show();
        MinimapZoomOut:Show();
        MiniMapTracking:Show();
        MiniMapWorldMapButton:Hide();
    end
end
local modifyMinimapLayout = function()
    frame = CreateFrame("Frame",nil,BurlexUID);
    frame:SetWidth(158);
    frame:SetHeight(158);
    frame:SetPoint("CENTER",0,54);

    -- new coding
    Minimap:SetMaskTexture("Interface\\AddOns\\BurlexUID\\media\\MinimapMask")
    MinimapBackdrop:SetBackdropBorderColor(0.75, 0.75, 0.75)
    MinimapBackdrop:SetBackdropColor(0.15, 0.15, 0.15, 0.0)
    MinimapBackdrop:SetAlpha(1.0)
    -- new coding end

    Minimap:SetParent(frame);
    Minimap:SetWidth(158);
    Minimap:SetHeight(158);
    Minimap:ClearAllPoints();
    Minimap:SetPoint("CENTER");
    
    MinimapBackdrop:ClearAllPoints();
    MinimapBackdrop:SetPoint("CENTER",frame,"CENTER",-10,-24);

    MinimapZoneTextButton:SetParent(frame);
    MinimapZoneTextButton:ClearAllPoints();
    MinimapZoneTextButton:SetPoint("TOP",frame,"BOTTOM",5,-6); -- Location Name (updated)
    MinimapBorderTop:Hide();
    MinimapBorder:SetAlpha(0);
--    MinimapZoomIn:Hide();
--    MinimapZoomOut:Hide();
    
    
    -- Dungeon Icon Relocation -> start
    MiniMapInstanceDifficulty:SetPoint("TOPLEFT", frame, -49, 21); -- Updated
    GuildInstanceDifficulty:SetPoint("TOPLEFT", frame, -49, 21); -- Updated
    -- Dungeon Icon Relocation -> end
    
    -- Clock Relocation -> start
    TimeManagerClockButton:SetPoint("TOP",frame,-2,29);
    local clockFrame, clockTime = TimeManagerClockButton:GetRegions();
    clockFrame:Hide();
    clockTime:SetFont("Interface\\AddOns\\BurlexUID\\media\\font-ariblk.ttf", 9, "THINOUTLINE");
    clockTime:SetTextColor(1, 1, 1);
    -- Clock Relocation -> end
    
    -- Time Frame Relocation -> start
    local iconsize = 32;
    local timeFont = "Interface\\AddOns\\BurlexUID\\media\\font-ariblk.ttf";
    local timeText = "Interface\\AddOns\\BurlexUID\\media\\minimap_button2";

    GameTimeFrame:Show();  -- Make sure it shows

    local bu = _G["GameTimeFrame"];
    bu:SetWidth(iconsize);
    bu:SetHeight(iconsize);
    bu:SetHitRectInsets(0, 0, 0, 0);

    select(5, GameTimeFrame:GetRegions()):SetTextColor(1, 1, 1);
    select(5, GameTimeFrame:GetRegions()):SetFont(timeFont,12,"THINOUTLINE");
    select(5, GameTimeFrame:GetRegions()):ClearAllPoints();
    select(5, GameTimeFrame:GetRegions()):SetPoint("CENTER",bu,"CENTER",0,1);
    
    local gtft = bu:CreateTexture(nil,"ARTWORK");
    gtft:SetTexture(timeText);
    gtft:SetPoint("TOPLEFT", bu, "TOPLEFT", -2, 2);
    gtft:SetPoint("BOTTOMRIGHT", bu, "BOTTOMRIGHT", 2, -2);

    nt = bu:GetNormalTexture();
    nt:SetTexCoord(0,1,0,1);
    nt:SetAllPoints(bu);

    bu:SetPoint("TOPRIGHT", frame, 47, 7);
    -- Time Frame Relocation -> end
    
    -- Zoom In/Out Relocation -> start
    MinimapZoomIn:Show();
    MinimapZoomIn:SetPoint("BOTTOMRIGHT", frame, 16, -16);
    MinimapZoomOut:Show();
    MinimapZoomOut:SetPoint("BOTTOMLEFT", frame, -16, -16);
    -- Zoom In/Out Relocation -> end
    
    MiniMapTracking:Hide();
    MiniMapWorldMapButton:Hide();
    
    Minimap.overlay = Minimap:CreateTexture(nil,"OVERLAY");
    Minimap.overlay:SetWidth(256);
    Minimap.overlay:SetHeight(256); 
    Minimap.overlay:SetTexture("Interface\\AddOns\\BurlexUID\\media\\map-overlay");
    Minimap.overlay:SetPoint("CENTER");
    Minimap.overlay:SetBlendMode("ADD");    
    
    frame:EnableMouse(true);
    frame:EnableMouseWheel(true);    
    frame:SetScript("OnMouseWheel",function()
        if (arg1 > 0) then Minimap_ZoomIn()
        else Minimap_ZoomOut() end
    end);
end;
local createMinimapCoords = function()
    local map = CreateFrame("Frame",nil,BurlexUID);
    map.coords = map:CreateFontString(nil,"BACKGROUND","GameFontNormalSmall");
    map.coords:SetWidth(128);
    map.coords:SetHeight(12);
    map.coords:SetPoint("TOP","MinimapZoneTextButton","BOTTOM",0,-6);
    map:HookScript("OnUpdate", function()
        updateButtons();
        do -- update minimap coordinates
            local x,y = GetPlayerMapPosition("player");
            if (not x) or (not y) then return; end
            map.coords:SetText(format("%.1f, %.1f",x*100,y*100));
        end
    end);
    map:HookScript("OnEvent",function()
        if (event == "ZONE_CHANGED" or event == "ZONE_CHANGED_INDOORS" or event == "ZONE_CHANGED_NEW_AREA") then
            if IsInInstance() then map.coords:Hide() else map.coords:Show() end
            if (WorldMapFrame:IsVisible()) then SetMapToCurrentZone(); end
        elseif (event == "ADDON_LOADED") then
            print(arg1);
        end
        local LastFrame = UIErrorsFrame;
        for i = 1, NUM_EXTENDED_UI_FRAMES do
            local bar = _G["WorldStateCaptureBar"..i];
            if (bar and bar:IsShown()) then             
                bar:ClearAllPoints();
                bar:SetPoint("TOP",LastFrame,"BOTTOM");            
                LastFrame = self;
            end
        end
    end);
    map:RegisterEvent("ZONE_CHANGED");
    map:RegisterEvent("ZONE_CHANGED_INDOORS");
    map:RegisterEvent("ZONE_CHANGED_NEW_AREA");
    map:RegisterEvent("UPDATE_WORLD_STATES");    
    map:RegisterEvent("UPDATE_BATTLEFIELD_SCORE");    
    map:RegisterEvent("PLAYER_ENTERING_WORLD");
    map:RegisterEvent("PLAYER_ENTERING_BATTLEGROUND");
    map:RegisterEvent("WORLD_STATE_UI_TIMER_UPDATE");    
end
---------------------------------------------------------------------------
function module:OnInitialize()
    addon.options.args["minimap"] = {
        name = "toggle Minimap Button Hiding", type="input",
        get = function(info) return buidChar and buidChar.MapButtons; end,
        set = function(info,val)
            if (val == "" and buidChar.MapButtons == true) or (val == "off") then
                buidChar.MapButtons = nil;
                addon:Print("Minimap Button Hiding Disabled");
            elseif (val == "" and not buidChar.MapButtons) or (val == "on") then
                buidChar.MapButtons = true;
                addon:Print("Minimap Button Hiding Enabled");
            end
        end
    };
end
function module:OnEnable()
    if (checkThirdParty()) then return; end
    modifyMinimapLayout();
    createMinimapCoords();
--    LFGSearchStatus:ClearAllPoints();
--    LFGSearchStatus:SetPoint("BOTTOM",BurlexUID,"TOP",0,100);
    ConsolidatedBuffs:ClearAllPoints();
    ConsolidatedBuffs:SetPoint("TOPRIGHT",-13,-13);    
end
